from staros import StarClient


cli = StarClient("login", "password", "10.21.219.18", 22)

# 1) get number of enode-b associations
print cli.getEnodebAssociatNum()
#response
#{'Total ENodeB': '332'}

# 2) get full number of total subscribers and subscribers on mme/pgw/sgw/ggsn/sgsn
print cli.getsubssessionmain()
#response
#{
# 'utran': {'sgsn': '0', 'ggsn-pdp-type-ipv4': '19351', 'sgsn-pdp-type-ipv4': '0'},
# 'total': {'active': '61289', 'Total Subscribers': '75281'},
# 'eutran': {'mme': '18742', 'pgw-gtp-ipv4': '18447', 'sgw-gtp-ipv4': '18786'}
# }


# 3) get some info about msisdn sessions
print cli.getsubscrmsisdn("375298766719")
#response
#{
#   4: {
#               'msisdn': '375298766719', 'callid': '24c9bd29', 'ip-address': '100.125.194.236', 'imsi': '257027519540042',
#               'sesstype': {
#                               'Call state': 'Connected',
#                               'Access CSCF status': 'Not Applicable',
#                               'Access tech': 'eUTRAN',
#                               'Access type': 'sgw-gtp-ipv4',
#                               'Network type': 'IP',
#                               'Link status': 'Online/Active'
#                           }
#       },
#   5: {
#               'msisdn': '375298766719', 'callid': '24c9bd2a', 'ip-address': '100.125.194.236', 'imsi': '257027519540042',
#               'sesstype': {
#                               'Call state': 'Connected',
#                               'Access CSCF status': 'Not Attached',
#                               'Access tech': 'eUTRAN',
#                               'Access type': 'pgw-gtp-ipv4',
#                               'Network type': 'IP',
#                               'Link status': 'Online/Active'
#                           }
#       },
#   1: {
#               'msisdn': 'n/a', 'callid': '0c5aed12', 'ip-address': '100.73.22.252', 'imsi': '257027518529391',
#               'sesstype': {
#                               'Call state': 'Connected',
#                               'Access CSCF status': 'Not Applicable',
#                               'Access tech': 'eUTRAN',
#                               'Access type': 's1-mme',
#                               'Network type': 'IP',
#                               'Link status': 'Online/Active'
#                           }
#       },
#   2: {
#               'msisdn': 'n/a', 'callid': '2dba6ef5', 'ip-address': '100.125.194.236', 'imsi': '257027519540042',
#               'sesstype': {
#                               'Call state': 'Connected',
#                               'Access CSCF status': 'Not Applicable',
#                               'Access tech': 'eUTRAN',
#                               'Access type': 's1-mme',
#                               'Network type': 'IP',
#                               'Link status': 'Online/Active'
#                           }
#       },
#   3: {
#               'msisdn': '375298766719', 'callid': '0cf2bf6e', 'ip-address': '100.73.22.252', 'imsi': '257027518529391',
#               'sesstype': {
#                               'Call state': 'Connected',
#                               'Access CSCF status': 'Not Applicable',
#                               'Access tech': 'eUTRAN',
#                               'Access type': 'sgw-gtp-ipv4',
#                               'Network type': 'IP',
#                               'Link status': 'Online/Active'
#                           }
#       },
# 'sessnum': 5
# }
#
# if not found response
# {'sessnum': 0}




import paramiko, time


def getsshdata(host, port, user, passwd, cmd):
        ssh = paramiko.SSHClient()
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.load_system_host_keys()
        ssh.set_missing_host_key_policy(paramiko.WarningPolicy())
        conn = ssh.connect(host, port=port, username=user, password=passwd, timeout=5, look_for_keys=False)
        remote_conn = ssh.invoke_shell()
        cnt = remote_conn.send(cmd)
        time.sleep(2)
        output = remote_conn.recv(10000)
        return output



#!/usr/bin/python

from connection import _getsshdata
import connection
import outputparsing
import threadingfind
import datetime
import json


class StarClient:
    def __init__(self, username, password, host, port):
        self.username = username
        self.password = password
        self.host = host
        self.port = port

    def get_subs_msisdn(self, msisdn):
        data = connection._getsshdata3(self.host, self.port, self.username, self.password, "show subscribers msisdn " + msisdn+"\n")
        return outputparsing._getsubscribermsisdn(str(data))

    def get_subs_session_main(self):
        data = connection._getsshdata1(self.host, self.port, self.username, self.password, "show subscribers summary\n")
        return outputparsing._parseshowsess(str(data))

    def get_subs_full_imsi(self,imsi):
        data = _getsshdata(self.host, self.port, self.username, self.password, "show subscribers msisdn " + imsi + "\n")

    def get_enodeb_associat_num(self):
        data = connection._getsshdata2(self.host, self.port, self.username, self.password, "show mme-service enodeb-association summary\n")
        return outputparsing._parseEnodebAssoc(str(data))

    def clear_subs_msisdn(self, msisdn):
        data = connection._getsshdata1(self.host, self.port, self.username, self.password, "clear subscribers msisdn "+msisdn+" -noconfirm\n")
        return outputparsing._parseClearSubsc(str(data))

    def clear_subs_imsi(self, imsi):
        data = connection._getsshdata1(self.host, self.port, self.username, self.password, "clear subscribers imsi "+imsi+" -noconfirm\n")
        return outputparsing._parseClearSubsc(str(data))

    def get_device_info(self):
        data = connection._getsshdata2(self.host, self.port, self.username, self.password, "show version\n")
        return outputparsing._parse_device_info(str(data))

    def get_subs_full_msisdn(self,msisdn):
        data = connection._getsshdata3(self.host, self.port, self.username, self.password, "show subscribers full msisdn " + msisdn + "\n")
        try:
            outputparsing._get_full_subs_sess_info(str(data))
        except:
            return "Subscriber offline"
        #print data

    def clear_dns_cache_all_Gn(self):
        data = connection._getsshdata4dnsClearContextGn(self.host, self.port, self.username, self.password)
        ddd = outputparsing._clear_dns_gn_parse(data)
        if ddd == True:
            return "DNS cache cleared successful"
        else:
            return "Failed"

    def find_subs_core_list(self, msisdn, ggsnlist):
        ooo = threadingfind.find2(self.port, self.username, self.password, msisdn, ggsnlist)
        return ooo

    def find_subs_core_list_imsi(self, imsi, ggsnlist):
        start = datetime.datetime.now()
        ooo = threadingfind.find2imsi(self.port, self.username, self.password, imsi, ggsnlist)
        end = datetime.datetime.now()
        res = end-start
        ooo.update({"seconds": res.total_seconds()})
        return ooo




import threading
import connection
import outputparsing

out = {}

def gethostname(host,port,username,password):
    data = connection._getsshdata5(host, port, username, password, "show version\n")
    return outputparsing._parse_hostname(data)


def daemon(host, port, username, password, msisdn):
    #print "start 1"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    #print data
    ppp = outputparsing._getsubscribermsisdn(str(data))
    #print str(hoho) + " "+ str(ppp)
    if ppp.__len__()>1:
        hoho = gethostname(host, port, username, password)
        out.update({hoho : ppp})

    #print "stop 1"


def daemon1imsi(host, port, username, password, imsi):
    #print "start 1"
    data = connection._getsshdata3(host, port, username, password, "show subscribers imsi " + imsi + "\n")
    #print data
    ppp = outputparsing._getsubscribermsisdn(str(data))
    #print str(hoho) + " "+ str(ppp)
    if ppp.__len__()>1:
        hoho = gethostname(host, port, username, password)
        out.update({hoho : ppp})

    #print "stop 1"

def daemon1(host,port,username,password,msisdn):
    #print "start 2"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp1 = outputparsing._getsubscribermsisdn(str(data))
    hoho1 = gethostname(host,port,username,password)
    if ppp1['sessnum']!=0:
        out.update({hoho1: ppp1})
    #print "stop 2"


def daemon2(host,port,username,password,msisdn):
    #print "start 3"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp2 = outputparsing._getsubscribermsisdn(str(data))
    hoho2 = gethostname(host,port,username,password)
    if ppp2['sessnum']!=0:
        out.update({hoho2: ppp2})
    #print "stop 3"

def daemon3(host,port,username,password,msisdn):
    #print "start 4"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp3 = outputparsing._getsubscribermsisdn(str(data))
    hoho3 = gethostname(host,port,username,password)
    if ppp3['sessnum']!=0:
        out.update({hoho3: ppp3})
    #print "stop 4"


def daemon4(host,port,username,password,msisdn):
    #print "start 5"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp4 = outputparsing._getsubscribermsisdn(str(data))
    hoho4 = gethostname(host,port,username,password)
    if ppp4['sessnum']!=0:
        out.update({hoho4: ppp4})
    #print "stop 5"

def daemon5(host,port,username,password,msisdn):
    #print "start 6"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp5 = outputparsing._getsubscribermsisdn(str(data))
    hoho5 = gethostname(host,port,username,password)
    if ppp5['sessnum']!=0:
        out.update({hoho5: ppp5})
    #print "stop 6"

def daemon6(host,port,username,password,msisdn):
    #print "start 7"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp6 = outputparsing._getsubscribermsisdn(str(data))
    hoho6 = gethostname(host,port,username,password)
    if ppp6['sessnum']!=0:
        out.update({hoho6: ppp6})
    #print "stop 7"

def daemon7(host,port,username,password,msisdn):
    #print "start 8"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp7 = outputparsing._getsubscribermsisdn(str(data))
    hoho7 = gethostname(host,port,username,password)
    if ppp7['sessnum']!=0:
        out.update({hoho7: ppp7})
    #print "stop 8"


def daemon8(host,port,username,password,msisdn):
    #print "start 9"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp8 = outputparsing._getsubscribermsisdn(str(data))
    hoho8 = gethostname(host,port,username,password)
    if ppp8['sessnum']!=0:
        out.update({hoho8: ppp8})
    #print "stop 9"


def daemon9(host,port,username,password,msisdn):
    #print "start 10"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp9 = outputparsing._getsubscribermsisdn(str(data))
    hoho9 = gethostname(host,port,username,password)
    if ppp9['sessnum']!=0:
        out.update({hoho9: ppp9})
    #print "stop 10"

def daemon10(host,port,username,password,msisdn):
    #print "start 11"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp10 = outputparsing._getsubscribermsisdn(str(data))
    hoho10 = gethostname(host,port,username,password)
    if ppp10['sessnum']!=0:
        out.update({hoho10: ppp10})
    #print "stop 11"


def daemon11(host,port,username,password,msisdn):
    #print "start 12"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp11 = outputparsing._getsubscribermsisdn(str(data))
    hoho11 = gethostname(host,port,username,password)
    if ppp11['sessnum']!=0:
        out.update({hoho11: ppp11})
    #print "stop 12"


def daemon12(host,port,username,password,msisdn):
    #print "start 13"
    data = connection._getsshdata3(host, port, username, password, "show subscribers msisdn " + msisdn + "\n")
    ppp12 = outputparsing._getsubscribermsisdn(str(data))
    hoho12 = gethostname(host,port,username,password)
    if ppp12['sessnum']!=0:
        out.update({hoho12: ppp12})
    #print "stop 13"


def find(port,username,password,msisdn,ggsnlist):
    num = len(ggsnlist)

    if num == 1:
        a = threading.Thread(name='daemon', target=daemon(ggsnlist[0],port,username,password,msisdn))
        a.setDaemon(True)
        a.start()
        a.join()
    elif num == 2:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        a.setDaemon(True)
        b.setDaemon(True)
        a.start(),b.start()
        a.join(),b.join()
    elif num ==3:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True)
        a.start(),b.start(),c.start()
        a.join(),b.join(),c.join()
    elif num ==4:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True)
        a.start(),b.start(),c.start(),d.start()
        a.join(),b.join(),c.join(),d.join()
    elif num ==5:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start()
        a.join(),b.join(),c.join(),d.join(),e.join()
    elif num ==6:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join()
    elif num ==7:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        g = threading.Thread(name='daemon6', target=daemon6, args=(ggsnlist[6],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True),g.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start(),g.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join(),g.join()
    elif num ==8:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        g = threading.Thread(name='daemon6', target=daemon6, args=(ggsnlist[6],port,username,password,msisdn))
        h = threading.Thread(name='daemon7', target=daemon7, args=(ggsnlist[7],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True),g.setDaemon(True),h.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start(),g.start(),h.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join(),g.join(),h.join()
    elif num ==9:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        g = threading.Thread(name='daemon6', target=daemon6, args=(ggsnlist[6],port,username,password,msisdn))
        h = threading.Thread(name='daemon7', target=daemon7, args=(ggsnlist[7],port,username,password,msisdn))
        i = threading.Thread(name='daemon8', target=daemon8, args=(ggsnlist[8],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True),\
        g.setDaemon(True),h.setDaemon(True),i.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start(),g.start(),h.start(),i.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join(),g.join(),h.join(),i.join()
    elif num ==10:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        g = threading.Thread(name='daemon6', target=daemon6, args=(ggsnlist[6],port,username,password,msisdn))
        h = threading.Thread(name='daemon7', target=daemon7, args=(ggsnlist[7],port,username,password,msisdn))
        i = threading.Thread(name='daemon8', target=daemon8, args=(ggsnlist[8],port,username,password,msisdn))
        j = threading.Thread(name='daemon9', target=daemon9, args=(ggsnlist[9],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True),\
        g.setDaemon(True),h.setDaemon(True),i.setDaemon(True),j.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start(),g.start(),h.start(),i.start(),j.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join(),g.join(),h.join(),i.join(),j.join()
    elif num ==11:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        g = threading.Thread(name='daemon6', target=daemon6, args=(ggsnlist[6],port,username,password,msisdn))
        h = threading.Thread(name='daemon7', target=daemon7, args=(ggsnlist[7],port,username,password,msisdn))
        i = threading.Thread(name='daemon8', target=daemon8, args=(ggsnlist[8],port,username,password,msisdn))
        j = threading.Thread(name='daemon9', target=daemon9, args=(ggsnlist[9],port,username,password,msisdn))
        k = threading.Thread(name='daemon10', target=daemon10, args=(ggsnlist[10],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True),\
        g.setDaemon(True),h.setDaemon(True),i.setDaemon(True),j.setDaemon(True),k.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start(),g.start(),h.start(),i.start(),j.start(),k.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join(),g.join(),h.join(),i.join(),j.join(),k.join()
    elif num ==12:
        a = threading.Thread(name='daemon', target=daemon, args=(ggsnlist[0],port,username,password,msisdn))
        b = threading.Thread(name='daemon1', target=daemon1, args=(ggsnlist[1],port,username,password,msisdn))
        c = threading.Thread(name='daemon2', target=daemon2, args=(ggsnlist[2],port,username,password,msisdn))
        d = threading.Thread(name='daemon3', target=daemon3, args=(ggsnlist[3],port,username,password,msisdn))
        e = threading.Thread(name='daemon4', target=daemon4, args=(ggsnlist[4],port,username,password,msisdn))
        f = threading.Thread(name='daemon5', target=daemon5, args=(ggsnlist[5],port,username,password,msisdn))
        g = threading.Thread(name='daemon6', target=daemon6, args=(ggsnlist[6],port,username,password,msisdn))
        h = threading.Thread(name='daemon7', target=daemon7, args=(ggsnlist[7],port,username,password,msisdn))
        i = threading.Thread(name='daemon8', target=daemon8, args=(ggsnlist[8],port,username,password,msisdn))
        j = threading.Thread(name='daemon9', target=daemon9, args=(ggsnlist[9],port,username,password,msisdn))
        k = threading.Thread(name='daemon10', target=daemon10, args=(ggsnlist[10],port,username,password,msisdn))
        l = threading.Thread(name='daemon11', target=daemon11, args=(ggsnlist[11],port,username,password,msisdn))
        a.setDaemon(True),b.setDaemon(True),c.setDaemon(True),d.setDaemon(True),e.setDaemon(True),f.setDaemon(True),\
        g.setDaemon(True),h.setDaemon(True),i.setDaemon(True),j.setDaemon(True),k.setDaemon(True),l.setDaemon(True)
        a.start(),b.start(),c.start(),d.start(),e.start(),f.start(),g.start(),h.start(),i.start(),j.start(),k.start(),l.start()
        a.join(),b.join(),c.join(),d.join(),e.join(),f.join(),g.join(),h.join(),i.join(),j.join(),k.join(),l.join()
    return out


def find2(port,username,password,msisdn,ggsnlist):
    num = len(ggsnlist)

    threads = []

    for val in range(0, num):
        thread1 = threading.Thread(target=daemon, args=(ggsnlist[val], port, username, password, msisdn))
        #thread1.setDaemon(True)
        thread1.start()
        threads.append(thread1)

    for thread in threads:
        thread.join()

    return out


def find2imsi(port,username,password,imsi,ggsnlist):
    num = len(ggsnlist)

    threads = []

    for val in range(0, num):
        thread1 = threading.Thread(target=daemon1imsi, args=(ggsnlist[val], port, username, password, imsi))
        #thread1.setDaemon(True)
        thread1.start()
        threads.append(thread1)

    for thread in threads:
        thread.join()

    return out




from setuptools import setup, find_packages
setup(name='staros',
      version='1.0',
      description='Module for communicate with staros device',
      long_description='Connection to staros device, like Cisco ASR5700 or Cisco ASR5000',
      classifiers=[ 'Development Status :: 3 - Alpha',
                    'License :: OSI Approved :: MIT License',
                    'Programming Language :: Python :: 2.7',
                    'Topic :: Text Processing :: Linguistic', ],
      keywords='staros ASR ASR5700 ASR5000',
#      url='http://github.com/storborg/funniest',
      author='Dzmitry Buynovskiy',
      author_email='imperituro@mail.com',
      license='MIT',
      packages=find_packages(include=['staros'], exclude=['staros.tests']),
      install_requires=['paramiko', 'datetime'],
      include_package_data=True,
      zip_safe=False)



#!/usr/bin/python
import re
from additionalparse import _get_subs_info_parse


def _parseshowsess(data):
    a1 = re.search(r'Active:\s{2,100}(\d{1,20})', data)
    a2 = re.search(r'sgw-gtp-ipv4:\s{2,100}(\d{1,20})', data)
    a3 = re.search(r'mme:\s{2,100}(\d{1,20})', data)
    a4 = re.search(r'ggsn-pdp-type-ipv4:\s{2,100}(\d{1,20})', data)
    a5 = re.search(r'sgsn:\s{2,100}(\d{1,20})', data)
    a6 = re.search(r'sgsn-pdp-type-ipv4:\s{2,100}(\d{1,20})', data)
    a7 = re.search(r'pgw-gtp-ipv4:\s{2,100}(\d{1,20})', data)
    a8 = re.search(r'Total\sSubscribers:\s{2,100}(\d{1,20})', data)
    res = {"total": {"Total Subscribers": a8.group(1),
                     "active":a1.group(1)},
           "utran": {"sgsn": a5.group(1),
                     "sgsn-pdp-type-ipv4": a6.group(1),
                     "ggsn-pdp-type-ipv4": a4.group(1)
                     },
           "eutran": {"mme": a3.group(1),
                      "sgw-gtp-ipv4": a2.group(1),
                      "pgw-gtp-ipv4": a7.group(1)
                      }
           }
    return res


def _parseEnodebAssoc(data):
    a1 = re.search(r'Total ENodeB Associations\s{2,100}:\s{1,10}(\d{1,20})', data)
    resp ={"Total ENodeB" : a1.group(1)}
    return resp


def _parseClearSubsc(data):
    a1 = re.search(r'No\ssubscribers\smatch\sthe\sspecified\scriteria', data)
    a2 = re.search(r'Number of subscribers cleared:\s{1,10}(\d{1,20})', data)
    if a1:
        return 'Not found'
    else:
        return 'Cleared: '+a2.group(1)


def _getsubscribermsisdn(data):
    #
    a1 = re.findall(r'.{6}\s\w{8}\s\d{9,20}\s\S+\s+\S+\s+\w{9}', data)
    #a2 = re.findall(r'.{6}\s\w{8}\s\d{9,20}\s\d{5,15}\s+\S+\s+\w{9}', data)
    #a2=[]
    i = 1
    num = 0
    resout = {}
    for elem in a1:
        el = re.findall(r'\b\S{3,50}', elem)
        type = _get_subs_info_parse(el[0])
        res = {i: {"sesstype":type,
                          "callid": el[1],
                          "imsi": el[2],
                          "msisdn": el[3],
                          "ip-address": el[4]}}
        num = i
        i += 1
        resout.update(res)

    #for elem1 in a2:
    #    el1 = re.findall(r'\b\S{3,50}', elem1)
    #    type1 = _get_subs_info_parse(el1[0])
    #    res1 = {i: {"sesstype":type1,
    #                        "callid": el1[1],
    #                        "imsi": el1[2],
    #                        "msisdn": el1[3],
    #                        "ip-address": el1[4]}}
    #    num = i
    #    i += 1
    #    resout.update(res1)

    resout.update({"sessnum":num})
    return resout


def _parse_device_info(data):
    a1 = re.search(r'\sImage\sVersion:\s{5,70}(\d{1,3}.\d{1,3}.\d{1,3})', data)
    a2 = re.search(r'\sImage Build Number:\s{3,100}(\d{1,20})', data)
    return {"Image Version":a1.group(1), "Image Build Number": a2.group(1)}


def _get_full_subs_sess_info(data):
    a1 = data.split("CAE Server Address")
    resout1 = {}
    num1=1
    for sess in a1:
        e1 = re.search(r'Username:\s(\d{5,20})|Username:\s{1,3}(.{3})', sess)
        user = ""
        if e1.group(1) is not None:
            user = e1.group(1)
        else:
            user = e1.group(2)
        e2 = re.search(r'source context:\s{1,3}(\S{1,20})', sess)
        e3 = re.search(r'destination context:\s{1,3}(\S{1,20})', sess)
        e4 = re.search(r'ip address:\s{1,3}(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})', sess)
        e5 = re.search(r'Nat ip address:\s{1,3}(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})', sess)
        natip = None
        try:
            natip = e5.group(1)
        except:
            natip = None
        e6 = re.search(r'ip pool name:\s{1,3}(\S{2,40})', sess)
        ippool = None
        try:
            ippool = e6.group(1)
        except:
            ippool = None
        e7 = re.search(r'\smsid:\s{1,3}(\d{5,20})', sess)
        res = {num1: {
                      "Username": user,
                      "source context": e2.group(1),
                      "destination context": e3.group(1),
                      "ip address": e4.group(1),
                      "Nat ip address": natip,
                      "ip pool name": ippool,
                      "msid": e7.group(1),
                     }
              }
        num1 += 1
        print res

    a2 = re.search(r'\sImage Build Number:\s{3,100}(\d{1,20})', data)
    #return {"Image Version":a1.group(1), "Image Build Number":a2.group(1)}


def _clear_dns_gn_parse(data):
    if re.search(r'(Cache cleared for the specificied criteria)', data).group(1) == 'Cache cleared for the specificied criteria':
        return True
    else:
        return False


def _parse_hostname(data):
    return re.search(r'.local.(\S{3,20})#', data).group(1)
